# -*- coding: utf8 -*-
'''
DB MODULE - ODBC Firebird
*******************************
***  DB MODULE - ODBC Firebird
*******************************
$RCSfile: dbmod_odbc_firebird.py,v $
$Revision: 1231 $
$Author: j.holetschek $
$Date: 2012-11-21 15:12:34 +0100 (Mi, 21. Nov 2012) $

The biocase.wrapper database module to access Firebird trough ODBC datasources.
You will need the mxODBC module to connect to a DSN via ODBC.
'''

import os
from string								import join
from biocase.wrapper.errorclasses 		import *
from biocase.wrapper.sql.base 			import sqlBase
from biocase.wrapper.dbmod.base_dbmod   import DBBasemodule

import logging
log = logging.getLogger("pywrapper.dbmod")


# uses inherited ANSI SQL apart from this:
#
# tables must be defined with "" and no "AS" supported, not need to include it

sqlBase.templates['alias'] = '#1 #2'
sqlBase.templates['attribute'] = '"#1"."#2"'
sqlBase.templates['table'] = '"#1"'


__syntax__ = '''SELECT [ALL | DISTINCT] [FIRST nExpr] [Alias.] "Select_Item" 
   [[AS] Column_Name] [, [Alias.] "Select_Item" [[AS] Column_Name] ...] 
   FROM [FORCE] [DatabaseName!] "Table" [Local_Alias] 
   [ [INNER | LEFT [OUTER] | RIGHT [OUTER] | FULL [OUTER] JOIN DatabaseName!] 
	  "Table" [Local_Alias] [ON JoinCondition ...]
	  [[INTO Destination] | [TO FILE FileName [ADDITIVE] | TO PRINTER [PROMPT] | TO SCREEN]] 
	  [PREFERENCE PreferenceName] [NOCONSOLE] [PLAIN] [NOWAIT]
	  [WHERE JoinCondition [AND JoinCondition ...] [AND | OR FilterCondition [AND | OR FilterCondition ...]]]
   [GROUP BY GroupColumn [, GroupColumn ...]] [HAVING FilterCondition] [UNION [ALL] SELECTCommand] 
   [ORDER BY Order_Item [ASC | DESC] [, Order_Item [ASC | DESC] ...]]
'''		



# ---------------------------------------------------------------------------------
# ---------------------------------------------------------------------------------
# ---------------------------------------------------------------------------------
class DBmodule(DBBasemodule):
	__version__ = 'ceODBC'
	__dbmod__	= u'generic ODBC DB module'
	

	# _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _
	def __init__(self, psfObj):
		# setting the psfObj reference to self.psfObj
		# call createDBconnection method
		DBBasemodule.__init__(self, psfObj)
		

	# ------------------   FUNCTION OVERLOAD OF BASE DBMOD MODULE   ------------------
	# --------------------------------------------------------------------------------
	def createDBconnection(self):
		import ceODBC as odbc
		loginParas = "DSN=%s;UID=%s;PWD=%s" % (self.psfObj.database, self.psfObj.user ,self.psfObj.password )
		conn = odbc.connect( loginParas )		
		return conn 


	
